@@ -4,7 +4,8 @@ structure and contents of a default TiddlyWebWiki instance
 
 from tiddlywebplugins.instancer.util import get_tiddler_locations
 
-from tiddlywebplugins.console.instance import store_contents
+from tiddlywebplugins.console.instance import (store_contents,
+    store_structure as console_store_structure)
 
 instance_config = {
     'system_plugins': ['tiddlywebwiki'],
@@ -62,3 +63,4 @@ store_structure = {
         }
     }
 }
+store_structure['bags'].update(console_store_structure['bags'])
